@@ -25,7 +25,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: XSECC14n20010315.cpp 1833341 2018-06-11 16:25:41Z scantor $
+ * $Id: XSECC14n20010315.cpp 1894293 2021-10-15 14:14:50Z scantor $
  *
  */
 
@@ -55,6 +55,11 @@ XERCES_CPP_NAMESPACE_USE
 #include <xalanc/XPath/XPathEvaluator.hpp>
 #include <xalanc/XPath/NodeRefList.hpp>
 
+// If this isn't defined, we're on Xalan 1.12+ and require modern C++
+#ifndef XALAN_USING_XALAN
+# define XALAN_USING_XALAN(NAME) using xalanc :: NAME;
+#endif
+
 // Namespace definitions
 XALAN_USING_XALAN(XPathEvaluator)
 XALAN_USING_XALAN(XercesDOMSupport)
