@@ -24,7 +24,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoKeyDSA.cpp 1894270 2021-10-14 20:39:26Z scantor $
+ * $Id: OpenSSLCryptoKeyDSA.cpp 1894616 2021-10-29 14:06:14Z scantor $
  *
  */
 #include <xsec/framework/XSECDefs.hpp>
@@ -43,6 +43,23 @@ XSEC_USING_XERCES(ArrayJanitor);
 
 #include <openssl/dsa.h>
 
+// Inline for older OpenSSL versions.
+#if (OPENSSL_VERSION_NUMBER <   0x10100000L)
+static int BN_bn2binpad(const BIGNUM *a, unsigned char *to, int tolen)
+{
+    int bytes = BN_num_bytes(a);
+
+    if (bytes > tolen) {
+        return -1;
+    }
+    while (bytes < tolen) {
+        *to++ = 0;
+        bytes++;
+    }
+    BN_bn2bin(a, to);
+    return tolen;
+}
+#endif
 
 OpenSSLCryptoKeyDSA::OpenSSLCryptoKeyDSA() : mp_dsaKey(NULL), mp_accumP(NULL), mp_accumQ(NULL), mp_accumG(NULL) {
 };
@@ -431,11 +448,9 @@ unsigned int OpenSSLCryptoKeyDSA::signBase64Signature(unsigned char * hashBuf,
     }
 
     return sigValLen;
-
 }
 
 
-
 XSECCryptoKey * OpenSSLCryptoKeyDSA::clone() const {
 
     OpenSSLCryptoKeyDSA * ret;
