@@ -24,7 +24,7 @@
  *
  * Author(s): Berin Lautenbach
  *
- * $Id: OpenSSLCryptoKeyRSA.cpp 1843562 2018-10-11 15:13:40Z scantor $
+ * $Id: OpenSSLCryptoKeyRSA.cpp 1894259 2021-10-14 18:22:11Z scantor $
  *
  */
 
@@ -413,7 +413,7 @@ OpenSSLCryptoKeyRSA::OpenSSLCryptoKeyRSA(EVP_PKEY *k) :
     if (k == NULL || EVP_PKEY_id(k) != EVP_PKEY_RSA)
         return; // Nothing to do with us
 
-    RSA *rsa = EVP_PKEY_get0_RSA(k);
+    const RSA *rsa = EVP_PKEY_get0_RSA(k);
 
     const BIGNUM *n=NULL, *e=NULL, *d=NULL;
     RSA_get0_key(rsa, &n, &e, &d);
