@@ -22,7 +22,7 @@
  *
  * TXFMXPathFilter := Class that performs XPath transforms
  *
- * $Id: TXFMXPathFilter.cpp 1833341 2018-06-11 16:25:41Z scantor $
+ * $Id: TXFMXPathFilter.cpp 1894293 2021-10-15 14:14:50Z scantor $
  *
  */
 
@@ -66,6 +66,11 @@ XERCES_CPP_NAMESPACE_USE
 #    pragma warning(default: 4267)
 #endif
 
+// If this isn't defined, we're on Xalan 1.12+ and require modern C++
+#ifndef XALAN_USING_XALAN
+# define XALAN_USING_XALAN(NAME) using xalanc :: NAME;
+#endif
+
 // Xalan namespace usage
 XALAN_USING_XALAN(XPathProcessorImpl)
 XALAN_USING_XALAN(XalanDOMString)
